@@ -1,7 +1,7 @@
 import typer
 from dotenv import load_dotenv
 
-from aoricaan_cli.src.api import api_local
+from aoricaan_cli.src.api import local
 from aoricaan_cli.src.enpoints import endpoints
 from aoricaan_cli.src.lambdas import lambdas
 from aoricaan_cli.src.layers import layers
@@ -13,5 +13,5 @@ app = typer.Typer()
 app.add_typer(endpoints.app, name='endpoint')
 app.add_typer(lambdas.app, name='lambda')
 app.add_typer(layers.app, name='layers')
-app.add_typer(api_local.app, name='api')
+app.add_typer(local.app, name='api')
 app.add_typer(project.app, name='project')
